JBoss Tools SVN: r31992 - in trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core: scanner and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: scabanovich
Date: 2011-06-09 18:36:21 -0400 (Thu, 09 Jun 2011)
New Revision: 31992
Added:
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigFieldDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigMethodDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigTypeDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/IConfigDefinition.java
Modified:
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeanDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeansDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMemberDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMethodDefinition.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/scanner/SeamDefinitionBuilder.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/Location.java
trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/SAXParser.java
Log:
JBIDE-9110
https://issues.jboss.org/browse/JBIDE-9110
Added: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigFieldDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigFieldDefinition.java (rev 0)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigFieldDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -0,0 +1,34 @@
+/*******************************************************************************
+ * Copyright (c) 2011 Red Hat, Inc.
+ * Distributed under license by Red Hat, Inc. All rights reserved.
+ * This program is made available under the terms of the
+ * Eclipse Public License v1.0 which accompanies this distribution,
+ * and is available at http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Red Hat, Inc. - initial API and implementation
+ ******************************************************************************/
+package org.jboss.tools.cdi.seam.config.core.definition;
+
+import org.jboss.tools.cdi.internal.core.impl.definition.FieldDefinition;
+
+/**
+ *
+ * @author Viacheslav Kabanovich
+ *
+ */
+public class ConfigFieldDefinition extends FieldDefinition implements IConfigDefinition {
+ protected SeamFieldDefinition config;
+
+ public ConfigFieldDefinition() {}
+
+ public void setConfig(SeamFieldDefinition config) {
+ this.config = config;
+ setOriginalDefinition(new TextSourceReference(config.getResource(), config.getNode()));
+ }
+
+ public SeamFieldDefinition getConfig() {
+ return config;
+ }
+
+}
Property changes on: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigFieldDefinition.java
___________________________________________________________________
Added: svn:mime-type
+ text/plain
Added: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigMethodDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigMethodDefinition.java (rev 0)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigMethodDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -0,0 +1,34 @@
+/*******************************************************************************
+ * Copyright (c) 2011 Red Hat, Inc.
+ * Distributed under license by Red Hat, Inc. All rights reserved.
+ * This program is made available under the terms of the
+ * Eclipse Public License v1.0 which accompanies this distribution,
+ * and is available at http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Red Hat, Inc. - initial API and implementation
+ ******************************************************************************/
+package org.jboss.tools.cdi.seam.config.core.definition;
+
+import org.jboss.tools.cdi.internal.core.impl.definition.MethodDefinition;
+
+/**
+ *
+ * @author Viacheslav Kabanovich
+ *
+ */
+public class ConfigMethodDefinition extends MethodDefinition implements IConfigDefinition {
+ protected SeamMethodDefinition config;
+
+ public ConfigMethodDefinition() {}
+
+ public void setConfig(SeamMethodDefinition config) {
+ this.config = config;
+ setOriginalDefinition(new TextSourceReference(config.getResource(), config.getNode()));
+ }
+
+ public SeamMethodDefinition getConfig() {
+ return config;
+ }
+
+}
Property changes on: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigMethodDefinition.java
___________________________________________________________________
Added: svn:mime-type
+ text/plain
Added: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigTypeDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigTypeDefinition.java (rev 0)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigTypeDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -0,0 +1,44 @@
+/*******************************************************************************
+ * Copyright (c) 2011 Red Hat, Inc.
+ * Distributed under license by Red Hat, Inc. All rights reserved.
+ * This program is made available under the terms of the
+ * Eclipse Public License v1.0 which accompanies this distribution,
+ * and is available at http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Red Hat, Inc. - initial API and implementation
+ ******************************************************************************/
+package org.jboss.tools.cdi.seam.config.core.definition;
+
+import org.jboss.tools.cdi.internal.core.impl.definition.FieldDefinition;
+import org.jboss.tools.cdi.internal.core.impl.definition.MethodDefinition;
+import org.jboss.tools.cdi.internal.core.impl.definition.TypeDefinition;
+
+/**
+ *
+ * @author Viacheslav Kabanovich
+ *
+ */
+public class ConfigTypeDefinition extends TypeDefinition implements IConfigDefinition {
+ protected SeamBeanDefinition config;
+
+ public ConfigTypeDefinition() {}
+
+ public void setConfig(SeamBeanDefinition config) {
+ this.config = config;
+ setOriginalDefinition(new TextSourceReference(config.getResource(), config.getNode()));
+ }
+
+ public SeamBeanDefinition getConfig() {
+ return config;
+ }
+
+ protected FieldDefinition newFieldDefinition() {
+ return new ConfigFieldDefinition();
+ }
+
+ protected MethodDefinition newMethodDefinition() {
+ return new ConfigMethodDefinition();
+ }
+
+}
Property changes on: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/ConfigTypeDefinition.java
___________________________________________________________________
Added: svn:mime-type
+ text/plain
Added: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/IConfigDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/IConfigDefinition.java (rev 0)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/IConfigDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -0,0 +1,20 @@
+/*******************************************************************************
+ * Copyright (c) 2011 Red Hat, Inc.
+ * Distributed under license by Red Hat, Inc. All rights reserved.
+ * This program is made available under the terms of the
+ * Eclipse Public License v1.0 which accompanies this distribution,
+ * and is available at http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Red Hat, Inc. - initial API and implementation
+ ******************************************************************************/
+package org.jboss.tools.cdi.seam.config.core.definition;
+
+/**
+ *
+ * @author Viacheslav Kabanovich
+ *
+ */
+public interface IConfigDefinition {
+ public SeamMemberDefinition getConfig();
+}
Property changes on: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/IConfigDefinition.java
___________________________________________________________________
Added: svn:mime-type
+ text/plain
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeanDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeanDefinition.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeanDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -23,10 +23,10 @@
*
*/
public class SeamBeanDefinition extends SeamMemberDefinition {
- boolean inline = false;
- IType type = null;
- List<SeamFieldDefinition> fields = new ArrayList<SeamFieldDefinition>();
- List<SeamMethodDefinition> methods = new ArrayList<SeamMethodDefinition>();
+ protected boolean inline = false;
+ protected IType type = null;
+ protected List<SeamFieldDefinition> fields = new ArrayList<SeamFieldDefinition>();
+ protected List<SeamMethodDefinition> methods = new ArrayList<SeamMethodDefinition>();
public SeamBeanDefinition() {}
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeansDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeansDefinition.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamBeansDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -89,7 +89,7 @@
for (SeamBeanDefinition def: beanDefinitions) {
IType type = def.getType();
- TypeDefinition typeDef = new TypeDefinition();
+ ConfigTypeDefinition typeDef = new ConfigTypeDefinition();
boolean replaces = def.getReplacesLocation() != null;
boolean modifies = def.getModifiesLocation() != null;
if(replaces || modifies) {
@@ -137,7 +137,8 @@
return null;
}
- private void mergeTypeDefinition(SeamBeanDefinition def, TypeDefinition typeDef, ConfigDefinitionContext context) {
+ private void mergeTypeDefinition(SeamBeanDefinition def, ConfigTypeDefinition typeDef, ConfigDefinitionContext context) {
+ typeDef.setConfig(def);
mergeAnnotations(def, typeDef, context);
List<FieldDefinition> fieldDefs = typeDef.getFields();
@@ -145,7 +146,7 @@
String n = fieldDef.getField().getElementName();
SeamFieldDefinition f = def.getField(n);
if(f != null) {
- fieldDef.setOriginalDefinition(new TextSourceReference(resource, f.getNode()));
+ ((ConfigFieldDefinition)fieldDef).setConfig(f);
mergeAnnotations(f, fieldDef, context);
}
}
@@ -156,6 +157,7 @@
if(method == null) continue;
SeamMethodDefinition m = def.getMethod(method);
if(m != null) {
+ ((ConfigMethodDefinition)methodDef).setConfig(m);
mergeAnnotations(m, methodDef, context);
List<ParameterDefinition> psDefs = methodDef.getParameters();
List<SeamParameterDefinition> ps = m.getParameters();
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMemberDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMemberDefinition.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMemberDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -13,6 +13,7 @@
import java.util.HashMap;
import java.util.Map;
+import org.eclipse.core.resources.IResource;
import org.jboss.tools.cdi.core.IJavaAnnotation;
import org.jboss.tools.cdi.seam.config.core.xml.Location;
import org.jboss.tools.cdi.seam.config.core.xml.SAXElement;
@@ -24,6 +25,7 @@
*
*/
public abstract class SeamMemberDefinition {
+ protected IResource resource;
protected SAXNode node;
protected SAXElement replaces = null;
protected SAXElement modifies = null;
@@ -33,6 +35,14 @@
public SeamMemberDefinition() {}
+ public void setResource(IResource resource) {
+ this.resource = resource;
+ }
+
+ public IResource getResource() {
+ return resource;
+ }
+
public void setNode(SAXNode node) {
this.node = node;
}
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMethodDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMethodDefinition.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/definition/SeamMethodDefinition.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -21,8 +21,8 @@
*
*/
public class SeamMethodDefinition extends SeamMemberDefinition {
- IMethod method;
- List<SeamParameterDefinition> parameters = new ArrayList<SeamParameterDefinition>();
+ protected IMethod method;
+ protected List<SeamParameterDefinition> parameters = new ArrayList<SeamParameterDefinition>();
public SeamMethodDefinition() {}
@@ -36,6 +36,7 @@
}
public void addParameter(SeamParameterDefinition p) {
+ p.setParent(this);
parameters.add(p);
}
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/scanner/SeamDefinitionBuilder.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/scanner/SeamDefinitionBuilder.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/scanner/SeamDefinitionBuilder.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -127,6 +127,7 @@
private SeamBeanDefinition scanBean(SAXElement element, IType type, boolean inline) {
addDependency(type);
SeamBeanDefinition def = new SeamBeanDefinition();
+ def.setResource(resource);
def.setInline(inline);
def.setNode(element);
def.setType(type);
@@ -185,6 +186,7 @@
private SeamVirtualFieldDefinition scanVirtualProducerField(SAXElement element) {
SeamVirtualFieldDefinition def = new SeamVirtualFieldDefinition();
+ def.setResource(resource);
def.setNode(element);
IType type = Util.resolveType(element, project);
if(type == null) {
@@ -198,6 +200,7 @@
private SeamFieldDefinition scanField(SAXElement element, IField field) {
SeamFieldDefinition def = new SeamFieldDefinition();
+ def.setResource(resource);
def.setNode(element);
def.setField(field);
scanFieldContent(def, element);
@@ -236,6 +239,7 @@
private SeamFieldDefinition scanField(SAXAttribute a, IField field) {
SeamFieldDefinition def = new SeamFieldDefinition();
+ def.setResource(resource);
def.setNode(a);
def.setField(field);
def.addValue(a);
@@ -296,6 +300,7 @@
private SeamMethodDefinition scanMethod(SAXElement element, IType type) {
SeamMethodDefinition def = new SeamMethodDefinition();
+ def.setResource(resource);
def.setNode(element);
List<SAXElement> es = element.getChildElements();
for (SAXElement c: es) {
@@ -339,6 +344,7 @@
private SeamMethodDefinition scanConstructor(SAXElement element, IType type) {
SeamMethodDefinition def = new SeamMethodDefinition();
+ def.setResource(resource);
def.setNode(element);
if(Util.isParameters(element)) {
List<SAXElement> ps = element.getChildElements();
@@ -371,6 +377,7 @@
private SeamParameterDefinition scanParameter(SAXElement element) {
if(!Util.isConfigRelevant(element)) return null;
SeamParameterDefinition def = new SeamParameterDefinition();
+ def.setResource(resource);
def.setNode(element);
if(Util.isArray(element)) {
if(element.hasAttribute(CDISeamConfigConstants.ATTR_DIMENSIONS)) {
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/Location.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/Location.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/Location.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -10,22 +10,27 @@
******************************************************************************/
package org.jboss.tools.cdi.seam.config.core.xml;
-import org.eclipse.core.resources.IFile;
-
/**
*
* @author Viacheslav Kabanovich
*
*/
public class Location {
+ int line;
int start;
int length;
- public Location(int start, int length) {
+ public Location(int start, int length, int line) {
this.start = start;
this.length = length;
+ this.line = line;
}
+ /**
+ * Returns offset starting from the beginning of text.
+ *
+ * @return offset starting from the beginning of text
+ */
public int getStartPosition() {
return start;
}
@@ -34,6 +39,15 @@
return length;
}
+ /**
+ * Returns line number in text; first line has number 1.
+ *
+ * @return line number in text; first line has number 1
+ */
+ public int getLine() {
+ return line;
+ }
+
public boolean includes(int offset) {
return start <= offset && start + length >= offset;
}
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/SAXParser.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/SAXParser.java 2011-06-09 22:35:00 UTC (rev 31991)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.seam.config.core/src/org/jboss/tools/cdi/seam/config/core/xml/SAXParser.java 2011-06-09 22:36:21 UTC (rev 31992)
@@ -119,10 +119,10 @@
element.setName(qName);
element.setParent(current);
if(start >= 0) {
- element.setLocation(new Location(start, end - start));
+ element.setLocation(new Location(start, end - start, getLine(start)));
int ns = document.get().indexOf(qName, start);
if(ns >= start) {
- element.setNameLocation(new Location(ns, qName.length()));
+ element.setNameLocation(new Location(ns, qName.length(), getLine(ns)));
}
}
for (int i = 0; i < attributes.getLength(); i++) {
@@ -133,10 +133,10 @@
a.setValue(v);
int n_start = document.get().indexOf(n, start);
if(n_start >= 0) {
- a.setNameLocation(new Location(n_start, n.length()));
+ a.setNameLocation(new Location(n_start, n.length(), getLine(n_start)));
int v_start = document.get().indexOf('"', n_start);
if(v_start >= 0) {
- a.setValueLocation(new Location(v_start + 1, v.length()));
+ a.setValueLocation(new Location(v_start + 1, v.length(), getLine(v_start)));
}
}
//TODO
@@ -157,14 +157,14 @@
s = end - length;
}
currentText.append(append);
- currentTextLocation = new Location(s, length);
+ currentTextLocation = new Location(s, length, getLine(s));
}
public void endElement(String uri, String localName, String qName) throws SAXException {
int end = getCurrentLocation();
if(end > 0) {
int start = document.get().lastIndexOf("<", end);
- Location endLocation = new Location(start, end - start);
+ Location endLocation = new Location(start, end - start, getLine(start));
//TODO
}
if(currentText.length() > 0) {
@@ -192,6 +192,15 @@
String message = e.getMessage();
errors.add(message);
}
+
+ private int getLine(int start) {
+ try {
+ return document.getLineOfOffset(start);
+ } catch (BadLocationException e) {
+ CommonPlugin.getPluginLog().logError(e);
+ return -1;
+ }
+ }
}
14 years, 10 months
JBoss Tools SVN: r31991 - trunk/cdi/plugins/org.jboss.tools.cdi.core/src/org/jboss/tools/cdi/internal/core/impl/definition.
by jbosstools-commits@lists.jboss.org
Author: scabanovich
Date: 2011-06-09 18:35:00 -0400 (Thu, 09 Jun 2011)
New Revision: 31991
Modified:
trunk/cdi/plugins/org.jboss.tools.cdi.core/src/org/jboss/tools/cdi/internal/core/impl/definition/TypeDefinition.java
Log:
JBIDE-9110
https://issues.jboss.org/browse/JBIDE-9110
Modified: trunk/cdi/plugins/org.jboss.tools.cdi.core/src/org/jboss/tools/cdi/internal/core/impl/definition/TypeDefinition.java
===================================================================
--- trunk/cdi/plugins/org.jboss.tools.cdi.core/src/org/jboss/tools/cdi/internal/core/impl/definition/TypeDefinition.java 2011-06-09 22:33:23 UTC (rev 31990)
+++ trunk/cdi/plugins/org.jboss.tools.cdi.core/src/org/jboss/tools/cdi/internal/core/impl/definition/TypeDefinition.java 2011-06-09 22:35:00 UTC (rev 31991)
@@ -52,7 +52,7 @@
Set<IProcessAnnotatedMemberFeature> extensions = context.getProject().getExtensionManager().getProcessAnnotatedMemberFeature();
IField[] fs = getType().getFields();
for (int i = 0; i < fs.length; i++) {
- FieldDefinition f = new FieldDefinition();
+ FieldDefinition f = newFieldDefinition();
f.setTypeDefinition(this);
f.setField(fs[i], context, flags);
for (IProcessAnnotatedMemberFeature e: extensions) {
@@ -65,7 +65,7 @@
IMethod[] ms = getType().getMethods();
boolean hasConstructor = false;
for (int i = 0; i < ms.length; i++) {
- MethodDefinition m = new MethodDefinition();
+ MethodDefinition m = newMethodDefinition();
m.setTypeDefinition(this);
m.setMethod(ms[i], context, flags);
for (IProcessAnnotatedMemberFeature e: extensions) {
@@ -86,6 +86,14 @@
}
}
+ protected FieldDefinition newFieldDefinition() {
+ return new FieldDefinition();
+ }
+
+ protected MethodDefinition newMethodDefinition() {
+ return new MethodDefinition();
+ }
+
public void setBeanConstructor(boolean b) {
hasBeanConstructor = b;
}
14 years, 10 months
JBoss Tools SVN: r31990 - in trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor: form and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: scabanovich
Date: 2011-06-09 18:33:23 -0400 (Thu, 09 Jun 2011)
New Revision: 31990
Modified:
trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/TreeFormPage.java
trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/form/SampleTreeForm.java
Log:
JBIDE-9110
https://issues.jboss.org/browse/JBIDE-9110
Modified: trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/TreeFormPage.java
===================================================================
--- trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/TreeFormPage.java 2011-06-09 21:58:49 UTC (rev 31989)
+++ trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/TreeFormPage.java 2011-06-09 22:33:23 UTC (rev 31990)
@@ -29,6 +29,7 @@
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITextOperationTarget;
+import org.eclipse.jface.text.ITextSelection;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.ISelectionProvider;
@@ -195,6 +196,7 @@
// ISelectionChangedListener
public void selectionChanged(SelectionChangedEvent event) {
+ if(event.getSelection() instanceof ITextSelection) return;
XModelObject xmo = getModelObject(event.getSelection());
if(selection == xmo) return;
selection = xmo;
@@ -275,7 +277,7 @@
}
private XModelObject getModelObject(ISelection selection) {
- if(selection == null || selection.isEmpty()) return null;
+ if(!(selection instanceof IStructuredSelection) || selection.isEmpty()) return null;
IStructuredSelection s = (IStructuredSelection)selection;
Object o = s.getFirstElement();
return (o instanceof XModelObject) ? (XModelObject)o : null;
Modified: trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/form/SampleTreeForm.java
===================================================================
--- trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/form/SampleTreeForm.java 2011-06-09 21:58:49 UTC (rev 31989)
+++ trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/editor/form/SampleTreeForm.java 2011-06-09 22:33:23 UTC (rev 31990)
@@ -16,6 +16,7 @@
import org.jboss.tools.common.editor.SelectionNotifier;
import org.jboss.tools.common.editor.XModelObjectTreeViewComponent;
+import org.eclipse.jface.text.ITextSelection;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -141,7 +142,7 @@
Viewer viewer = tree.getViewer();
ISelection oldSelection = viewer.getSelection();
ISelection newSelection = event.getSelection();
- if (oldSelection.equals(newSelection)) return;
+ if (oldSelection.equals(newSelection) || newSelection instanceof ITextSelection) return;
viewer.setSelection(newSelection);
if(viewer.getSelection().isEmpty() && !oldSelection.isEmpty()) {
viewer.setSelection(oldSelection);
14 years, 10 months
JBoss Tools SVN: r31989 - trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal.
by jbosstools-commits@lists.jboss.org
Author: akazakov
Date: 2011-06-09 17:58:49 -0400 (Thu, 09 Jun 2011)
New Revision: 31989
Modified:
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java
Log:
https://issues.jboss.org/browse/JBIDE-9088
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java 2011-06-09 21:58:28 UTC (rev 31988)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java 2011-06-09 21:58:49 UTC (rev 31989)
@@ -10,8 +10,6 @@
******************************************************************************/
package org.jboss.tools.jst.web.kb.internal;
-import java.util.Arrays;
-import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
14 years, 10 months
JBoss Tools SVN: r31988 - in trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb: internal and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: akazakov
Date: 2011-06-09 17:58:28 -0400 (Thu, 09 Jun 2011)
New Revision: 31988
Modified:
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IKbProject.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IPageContext.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/PageContextFactory.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/KbProject.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/IComponent.java
trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/TagLibraryManager.java
Log:
https://issues.jboss.org/browse/JBIDE-9088
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IKbProject.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IKbProject.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IKbProject.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -11,6 +11,7 @@
package org.jboss.tools.jst.web.kb;
import org.eclipse.core.resources.IProjectNature;
+import org.eclipse.core.runtime.IPath;
import org.jboss.tools.jst.web.kb.taglib.ITagLibrary;
import org.jboss.tools.jst.web.kb.validation.IProjectValidationContext;
@@ -36,6 +37,13 @@
*/
ITagLibrary[] getTagLibraries(String uri);
+ /**
+ * Returns tag libraries by resource
+ * @param uri
+ * @return
+ */
+ ITagLibrary[] getTagLibraries(IPath path);
+
void resolve();
/**
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IPageContext.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IPageContext.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/IPageContext.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -12,10 +12,8 @@
import java.util.List;
import java.util.Map;
-import java.util.Set;
import org.eclipse.jface.text.IDocument;
-import org.jboss.tools.common.el.core.resolver.ELContext;
import org.jboss.tools.jst.web.kb.taglib.INameSpace;
import org.jboss.tools.jst.web.kb.taglib.ITagLibrary;
@@ -23,7 +21,7 @@
* Page context
* @author Alexey Kazakov
*/
-public interface IPageContext extends ELContext {
+public interface IPageContext extends IXmlContext {
/**
* Returns libraries which should be used in this context
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/PageContextFactory.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/PageContextFactory.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/PageContextFactory.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -134,6 +134,7 @@
public static boolean isPage(IFile file) {
IContentType type = IDE.getContentType(file);
String typeId = (type == null ? null : type.getId());
+ typeId = IncludeContextBuilder.getContextType(typeId);
return JSP_PAGE_CONTEXT_TYPE.equals(typeId) || FACELETS_PAGE_CONTEXT_TYPE.equals(typeId);
}
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/KbProject.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/KbProject.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/KbProject.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -28,7 +28,6 @@
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
-import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
@@ -114,6 +113,14 @@
/*
* (non-Javadoc)
+ * @see org.jboss.tools.jst.web.kb.IKbProject#getTagLibraries(org.eclipse.core.runtime.IPath)
+ */
+ public ITagLibrary[] getTagLibraries(IPath path) {
+ return libraries.getLibrariesArray(path);
+ }
+
+ /*
+ * (non-Javadoc)
* @see org.eclipse.core.resources.IProjectNature#configure()
*/
public void configure() throws CoreException {
@@ -1055,8 +1062,8 @@
public void printModifications() {
System.out.println(project.getName());
- System.out.println("" + modifications);
+ System.out.println("" + modifications); //$NON-NLS-1$
if(validationContext != null)
- System.out.println("validationContext " + validationContext.getModificationsSinceLastStore());
+ System.out.println("validationContext " + validationContext.getModificationsSinceLastStore()); //$NON-NLS-1$
}
}
\ No newline at end of file
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/internal/LibraryStorage.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -10,6 +10,8 @@
******************************************************************************/
package org.jboss.tools.jst.web.kb.internal;
+import java.util.Arrays;
+import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
@@ -51,6 +53,8 @@
return allLibrariesArray;
}
+ private static final ITagLibrary[] EMPTY_LIB_ARRAY = new ITagLibrary[0];
+
public ITagLibrary[] getLibrariesArray(String uri) {
ITagLibrary[] result = librariesByUriArray.get(uri);
if(result == null) {
@@ -59,7 +63,7 @@
if(libs!=null) {
result = libs.toArray(new ITagLibrary[0]);
} else {
- result = new ITagLibrary[0];
+ result = EMPTY_LIB_ARRAY;
}
librariesByUriArray.put(uri, result);
}
@@ -71,6 +75,17 @@
return librariesBySource.get(path);
}
+ public ITagLibrary[] getLibrariesArray(IPath path) {
+ ITagLibrary[] result = EMPTY_LIB_ARRAY;
+ synchronized(librariesBySource) {
+ Set<ITagLibrary> libs = librariesBySource.get(path);
+ if(libs!=null) {
+ result = libs.toArray(new ITagLibrary[0]);
+ }
+ }
+ return result;
+ }
+
public void addLibrary(ITagLibrary f) {
synchronized(allLibraries) {
allLibraries.add(f);
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/IComponent.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/IComponent.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/IComponent.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -10,6 +10,7 @@
******************************************************************************/
package org.jboss.tools.jst.web.kb.taglib;
+import org.eclipse.core.resources.IResource;
import org.jboss.tools.jst.web.kb.IPageContext;
import org.jboss.tools.jst.web.kb.IProposalProcessor;
import org.jboss.tools.jst.web.kb.KbQuery;
@@ -110,4 +111,10 @@
* @return parent tag lib.
*/
ITagLibrary getTagLib();
+
+ /**
+ * Returns the resource where this component is defined. May be a jar file.
+ * @return
+ */
+ IResource getResource();
}
\ No newline at end of file
Modified: trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/TagLibraryManager.java
===================================================================
--- trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/TagLibraryManager.java 2011-06-09 21:27:12 UTC (rev 31987)
+++ trunk/jst/plugins/org.jboss.tools.jst.web.kb/src/org/jboss/tools/jst/web/kb/taglib/TagLibraryManager.java 2011-06-09 21:58:28 UTC (rev 31988)
@@ -14,6 +14,7 @@
import java.io.IOException;
import java.net.URL;
+import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.wst.xml.core.internal.XMLCorePlugin;
import org.jboss.tools.jst.web.kb.IKbProject;
@@ -40,6 +41,19 @@
}
/**
+ * Returns all the tag libraries which defined in the file (TLD, facelet tag lib, composite component, etc.)
+ * @param file
+ * @return
+ */
+ public static ITagLibrary[] getLibraries(IFile file) {
+ IKbProject kbProject = KbProjectFactory.getKbProject(file.getProject(), true);
+ if(kbProject == null) {
+ return new ITagLibrary[0];
+ }
+ return kbProject.getTagLibraries(file.getFullPath());
+ }
+
+ /**
* Returns all tag libraries which are available in the project.
* @param project
* @return
@@ -74,7 +88,6 @@
}
} catch (IOException e) {
WebKbPlugin.getDefault().logError(e);
- return null;
}
return null;
14 years, 10 months
JBoss Tools SVN: r31987 - trunk/documentation/guides/JBDS_Release_Notes/en-US.
by jbosstools-commits@lists.jboss.org
Author: irooskov(a)redhat.com
Date: 2011-06-09 17:27:12 -0400 (Thu, 09 Jun 2011)
New Revision: 31987
Modified:
trunk/documentation/guides/JBDS_Release_Notes/en-US/Component_Versions.xml
Log:
updated with information concerning the removal of the Drools Rule engine as outlined in JBIDE-9052
Modified: trunk/documentation/guides/JBDS_Release_Notes/en-US/Component_Versions.xml
===================================================================
--- trunk/documentation/guides/JBDS_Release_Notes/en-US/Component_Versions.xml 2011-06-09 21:00:58 UTC (rev 31986)
+++ trunk/documentation/guides/JBDS_Release_Notes/en-US/Component_Versions.xml 2011-06-09 21:27:12 UTC (rev 31987)
@@ -26,4 +26,9 @@
The Enterprise Application Platform Server has been redefined for the enterprise market to a level where direct association to a community release can no longer be drawn.
</para>
</note>
+ <important>
+ <para>
+ The Drools Rule editor has been removed from this release. For further information on why this has occurred, see <ulink url="https://issues.jboss.org/browse/JBIDE-9052">JBIDE-9052</ulink>
+ </para>
+ </important>
</section>
14 years, 10 months
JBoss Tools SVN: r31986 - in trunk/ws: plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/utils and 4 other directories.
by jbosstools-commits@lists.jboss.org
Author: xcoulon
Date: 2011-06-09 17:00:58 -0400 (Thu, 09 Jun 2011)
New Revision: 31986
Added:
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services.gif
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services_error.gif
Removed:
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/customization.png
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/wsdl_file_obj.gif
Modified:
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/Resource.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethod.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethodMapping.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/RouteEndpoint.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/utils/ResourceMethodAnnotatedParameter.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriMappingsLabelProvider.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateCategory.java
trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateElement.java
trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/AbstractCommonTestCase.java
trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/SyncFileSystemStructureProvider.java
trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/WorkbenchTasks.java
trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceChangesTestCase.java
trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceMethodChangesTestCase.java
Log:
Fixing minor bugs related to UI error reporting and Metamodel updates, increasing test setup speed by skipping .svn folders.
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/Resource.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/Resource.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/Resource.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -186,7 +186,6 @@
String key = keys.get(javaMethod);
if (resourceMethods.containsKey(key)) {
ResourceMethod resourceMethod = resourceMethods.get(key);
-
Set<EnumElementChange> resourceMethodChanges = resourceMethod.merge(javaMethod, progressMonitor);
Set<EnumElementChange> changes = new HashSet<EnumElementChange>();
changes.addAll(resourceChanges);
@@ -215,8 +214,12 @@
Logger.debug("Added " + resourceMethod.toString());
}
} catch (InvalidModelElementException e) {
- Logger.warn("ResourceMethod '" + javaMethod.getElementName()
+ Logger.warn("ResourceMethod bound to '" + javaMethod.getElementName()
+ "' is not a valid JAX-RS ResourceMethod: " + e.getMessage());
+ if (resourceMethods.containsKey(javaMethod)) {
+ resourceMethods.remove(javaMethod);
+ }
+
}
}
}
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethod.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethod.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethod.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -120,7 +120,22 @@
getMapping().validate();
}
+ /**
+ * Sets a flag of whether the underlying java method has compilation errors
+ * or not. If true, also marke the parent resource with errors flag.
+ *
+ * @param h
+ * : true if the java element has errors, false otherwise
+ */
@Override
+ public void hasErrors(final boolean h) {
+ super.hasErrors(h);
+ if (hasErrors()) {
+ parentResource.hasErrors(true);
+ }
+ }
+
+ @Override
public final BaseElement.EnumKind getKind() {
return kind;
}
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethodMapping.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethodMapping.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/ResourceMethodMapping.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -186,6 +186,7 @@
marker.setAttribute(IMarker.LINE_NUMBER, pathParam.getLineNumber());
marker.setAttribute(IMarker.CHAR_START, pathParam.getCharStart());
marker.setAttribute(IMarker.CHAR_END, pathParam.getCharEnd());
+ this.resourceMethod.hasErrors(true);
}
}
}
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/RouteEndpoint.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/RouteEndpoint.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/metamodel/RouteEndpoint.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -5,6 +5,7 @@
import java.util.LinkedList;
import java.util.List;
+import org.jboss.tools.ws.jaxrs.core.internal.utils.Logger;
import org.jboss.tools.ws.jaxrs.core.utils.ResourceMethodAnnotatedParameter;
public class RouteEndpoint implements Comparable<RouteEndpoint> {
@@ -88,7 +89,9 @@
return h;
}
}
- throw new InvalidModelElementException("No HttpMethod annotation found for this endpoint: " + resourceMethods);
+ Logger.debug("No HttpMethod annotation found for this endpoint: " + resourceMethods);
+ return null;
+
}
private static String computeUriPathTemplate(LinkedList<ResourceMethod> resourceMethods) {
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/utils/ResourceMethodAnnotatedParameter.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/utils/ResourceMethodAnnotatedParameter.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.core/src/org/jboss/tools/ws/jaxrs/core/utils/ResourceMethodAnnotatedParameter.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -18,20 +18,20 @@
public class ResourceMethodAnnotatedParameter implements Validable, Comparable<ResourceMethodAnnotatedParameter> {
private final String parameterType;
-
+
private final String annotationType;
private final String annotationValue;
-
+
private final int charStart;
-
+
private final int charEnd;
-
+
private final int lineNumber;
-
/**
* Full constructor
+ *
* @param parent
* @param parameterName
* @param parameterType
@@ -41,8 +41,8 @@
* @param charEnd
* @param lineNumber
*/
- public ResourceMethodAnnotatedParameter(String parameterType,
- String annotationType, String annotationValue, int charStart, int charEnd, int lineNumber) {
+ public ResourceMethodAnnotatedParameter(String parameterType, String annotationType, String annotationValue,
+ int charStart, int charEnd, int lineNumber) {
super();
this.parameterType = parameterType;
this.annotationType = annotationType;
@@ -100,14 +100,25 @@
}
/**
- * Compares method parameters by their textual location
- * {@inheritDoc}
+ * Compares method parameters by their textual location {@inheritDoc}
+ *
* @param otherParam
* @return
*/
@Override
public int compareTo(ResourceMethodAnnotatedParameter otherParam) {
- return getCharStart() - otherParam.getCharStart();
+ return getCharStart() - otherParam.getCharStart();
}
-
+
+ /*
+ * (non-Javadoc)
+ *
+ * @see java.lang.Object#toString()
+ */
+ @Override
+ public String toString() {
+ return "ResourceMethodAnnotatedParameter [parameterType=" + parameterType + ", annotationType="
+ + annotationType + ", annotationValue=" + annotationValue + "]";
+ }
+
}
Deleted: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/customization.png
===================================================================
(Binary files differ)
Added: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services.gif
===================================================================
(Binary files differ)
Property changes on: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services.gif
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Added: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services_error.gif
===================================================================
(Binary files differ)
Property changes on: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/restful_web_services_error.gif
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Deleted: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/icons/wsdl_file_obj.gif
===================================================================
(Binary files differ)
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriMappingsLabelProvider.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriMappingsLabelProvider.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriMappingsLabelProvider.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -37,7 +37,10 @@
@Override
public Image getImage(Object element) {
if (element instanceof UriPathTemplateCategory) {
- return JBossJaxrsUIPlugin.getDefault().createImage("wsdl_file_obj.gif");
+ if (((UriPathTemplateCategory) element).hasErrors()) {
+ return JBossJaxrsUIPlugin.getDefault().createImage("restful_web_services_error.gif");
+ }
+ return JBossJaxrsUIPlugin.getDefault().createImage("restful_web_services.gif");
} else if (element instanceof UriPathTemplateElement) {
if (((UriPathTemplateElement) element).hasErrors()) {
return JBossJaxrsUIPlugin.getDefault().createImage("url_mapping_error.gif");
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateCategory.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateCategory.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateCategory.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -91,6 +91,17 @@
Logger.debug("Input changed in UriPathTemplateCategory");
}
+ public boolean hasErrors() {
+ for (Route route : metamodel.getRoutes().getAll()) {
+ for (ResourceMethod resourceMethod : route.getResourceMethods()) {
+ if (resourceMethod.hasErrors()) {
+ return true;
+ }
+ }
+ }
+ return false;
+ }
+
@Override
public void dispose() {
}
Modified: trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateElement.java
===================================================================
--- trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateElement.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/plugins/org.jboss.tools.ws.jaxrs.ui/src/org/jboss/tools/ws/jaxrs/ui/cnf/UriPathTemplateElement.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -69,7 +69,12 @@
}
public boolean hasErrors() {
- return getLastMethod().hasErrors();
+ for (ResourceMethod resourceMethod : route.getResourceMethods()) {
+ if (resourceMethod.hasErrors()) {
+ return true;
+ }
+ }
+ return false;
}
/**
Modified: trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/AbstractCommonTestCase.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/AbstractCommonTestCase.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/AbstractCommonTestCase.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -27,6 +27,10 @@
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.rules.MethodRule;
+import org.junit.rules.TestWatchman;
+import org.junit.runners.model.FrameworkMethod;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
@@ -61,6 +65,24 @@
private ProjectSynchronizator synchronizor;
+ @Rule
+ public MethodRule watchman = new TestWatchman() {
+ @Override
+ public void starting(FrameworkMethod method) {
+ LOGGER.info("**********************************************************************************");
+ LOGGER.info("Starting test '{}'...", method.getName());
+ LOGGER.info("**********************************************************************************");
+ }
+
+ @Override
+ public void finished(FrameworkMethod method) {
+ LOGGER.info("**********************************************************************************");
+ LOGGER.info("Test '{}' finished.", method.getName());
+ LOGGER.info("**********************************************************************************");
+ }
+
+ };
+
@BeforeClass
public static void setupWorkspace() throws Exception {
long startTime = new Date().getTime();
Modified: trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/SyncFileSystemStructureProvider.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/SyncFileSystemStructureProvider.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/SyncFileSystemStructureProvider.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -35,17 +35,15 @@
*
*/
@SuppressWarnings("restriction")
-public class SyncFileSystemStructureProvider implements
- IImportStructureProvider {
+public class SyncFileSystemStructureProvider implements IImportStructureProvider {
- private static final Logger LOGGER = LoggerFactory
- .getLogger(SyncFileSystemStructureProvider.class);
+ private static final Logger LOGGER = LoggerFactory.getLogger(SyncFileSystemStructureProvider.class);
private final IPath source;
private final IPath destination;
- private final List<IPath> ignoredRelativePaths = new ArrayList<IPath>();
+ private final List<String> ignoredRelativePaths = new ArrayList<String>();
/**
* Creates an instance of <code>SyncFileSystemStructureProvider</code>.
@@ -61,6 +59,7 @@
/*
* (non-Javadoc) Method declared on IImportStructureProvider
*/
+ @Override
public List<File> getChildren(Object element) {
File folder = (File) element;
String[] children = folder.list();
@@ -69,28 +68,22 @@
for (int i = 0; i < childrenLength; i++) {
File sourceFile = new File(folder, children[i]);
- IPath relativeSourcePath = new Path(sourceFile.getAbsolutePath())
- .makeRelativeTo(source);
+ IPath relativeSourcePath = new Path(sourceFile.getAbsolutePath()).makeRelativeTo(source);
// always add the sub directories
- if (ignoredRelativePaths.contains(relativeSourcePath)) {
+ if (ignoredRelativePaths.contains(relativeSourcePath.lastSegment())) {
continue;
}
- if (sourceFile.isDirectory()) {
+ if (sourceFile.isDirectory() && !ignoredRelativePaths.contains(relativeSourcePath.lastSegment())) {
result.addAll(getChildren(sourceFile));
}
// only add the other files if they are missing or were modified in
// the destination destination
else {
- IPath relativeDestinationPath = destination
- .append(relativeSourcePath);
- File destinationFile = new File(
- relativeDestinationPath.toOSString());
- if (!destinationFile.exists()
- || destinationFile.lastModified() > sourceFile
- .lastModified()) {
- LOGGER.debug("Adding '" + relativeSourcePath
- + "' to sync operation.");
+ IPath relativeDestinationPath = destination.append(relativeSourcePath);
+ File destinationFile = new File(relativeDestinationPath.toOSString());
+ if (!destinationFile.exists() || destinationFile.lastModified() > sourceFile.lastModified()) {
+ LOGGER.debug("Adding '" + relativeSourcePath + "' to sync operation.");
result.add(sourceFile);
}
}
@@ -102,6 +95,7 @@
/*
* (non-Javadoc) Method declared on IImportStructureProvider
*/
+ @Override
public InputStream getContents(Object element) {
try {
return new FileInputStream((File) element);
@@ -114,6 +108,7 @@
/*
* (non-Javadoc) Method declared on IImportStructureProvider
*/
+ @Override
public String getFullPath(Object element) {
return ((File) element).getPath();
}
@@ -121,6 +116,7 @@
/*
* (non-Javadoc) Method declared on IImportStructureProvider
*/
+ @Override
public String getLabel(Object element) {
// Get the name - if it is empty then return the path as it is a file
@@ -136,11 +132,12 @@
/*
* (non-Javadoc) Method declared on IImportStructureProvider
*/
+ @Override
public boolean isFolder(Object element) {
return ((File) element).isDirectory();
}
- public void ignoreRelativeSourcePath(IPath relativePath) {
+ public void ignoreRelativeSourcePath(String relativePath) {
this.ignoredRelativePaths.add(relativePath);
}
Modified: trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/WorkbenchTasks.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/WorkbenchTasks.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/WorkbenchTasks.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -88,9 +88,9 @@
LOGGER.info("Target workspace location: " + targetWorkspace.getRoot().getRawLocation());
SyncFileSystemStructureProvider syncFileSystemStructureProvider = new SyncFileSystemStructureProvider(
projectSourcePath, project.getLocation());
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path(".svn"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path("target"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path("bin"));
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath(".svn");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath("target");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath("bin");
List<File> filesToImport = syncFileSystemStructureProvider.getChildren(projectSourcePath.toFile());
if (filesToImport != null && filesToImport.size() > 0) {
ImportOperation operation = new ImportOperation(project.getFullPath(), projectSourcePath.toFile(),
@@ -109,11 +109,12 @@
LOGGER.info("Removing added files from the target workspace");
// reverse detection operation
syncFileSystemStructureProvider = new SyncFileSystemStructureProvider(project.getLocation(), projectSourcePath);
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path("target"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path("bin"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path(".project"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path(".classpath"));
- syncFileSystemStructureProvider.ignoreRelativeSourcePath(new Path(".settings"));
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath("target");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath("bin");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath(".svn");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath(".project");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath(".classpath");
+ syncFileSystemStructureProvider.ignoreRelativeSourcePath(".settings");
List<File> filesToRemove = syncFileSystemStructureProvider.getChildren(project.getLocation().toFile());
for (File fileToRemove : filesToRemove) {
Assert.assertTrue("File not deleted : " + fileToRemove, fileToRemove.delete());
Modified: trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceChangesTestCase.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceMethodChangesTestCase.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceMethodChangesTestCase.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -29,7 +29,6 @@
import org.jboss.tools.ws.jaxrs.core.metamodel.Resources;
import org.jboss.tools.ws.jaxrs.core.metamodel.Route;
import org.junit.Assert;
-import org.junit.Ignore;
import org.junit.Test;
/**
@@ -247,7 +246,6 @@
}
@Test
- @Ignore
public void shouldBecomeSubresourceLocatorWhenRemovingHTTPMethodAnnotation() throws CoreException {
// pre-conditions
Resource resource = metamodel.getResources().getByTypeName(
14 years, 10 months
JBoss Tools SVN: r31985 - branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xulrunner.feature.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2011-06-09 16:54:19 -0400 (Thu, 09 Jun 2011)
New Revision: 31985
Added:
branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xulrunner.feature/.gitignore
Log:
.gitignore file
Added: branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xulrunner.feature/.gitignore
===================================================================
--- branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xulrunner.feature/.gitignore (rev 0)
+++ branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xulrunner.feature/.gitignore 2011-06-09 20:54:19 UTC (rev 31985)
@@ -0,0 +1 @@
+target
14 years, 10 months
JBoss Tools SVN: r31984 - branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xpcom.feature.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2011-06-09 16:54:07 -0400 (Thu, 09 Jun 2011)
New Revision: 31984
Added:
branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xpcom.feature/.gitignore
Log:
.gitignore file
Added: branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xpcom.feature/.gitignore
===================================================================
--- branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xpcom.feature/.gitignore (rev 0)
+++ branches/jbosstools-3.2.x/xulrunner/features/org.mozilla.xpcom.feature/.gitignore 2011-06-09 20:54:07 UTC (rev 31984)
@@ -0,0 +1 @@
+target
14 years, 10 months
JBoss Tools SVN: r31983 - branches/jbosstools-3.2.x/xulrunner/site.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2011-06-09 16:53:53 -0400 (Thu, 09 Jun 2011)
New Revision: 31983
Added:
branches/jbosstools-3.2.x/xulrunner/site/.gitignore
Log:
.gitignore file
Added: branches/jbosstools-3.2.x/xulrunner/site/.gitignore
===================================================================
--- branches/jbosstools-3.2.x/xulrunner/site/.gitignore (rev 0)
+++ branches/jbosstools-3.2.x/xulrunner/site/.gitignore 2011-06-09 20:53:53 UTC (rev 31983)
@@ -0,0 +1 @@
+target
14 years, 10 months
--- trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceChangesTestCase.java 2011-06-09 20:54:19 UTC (rev 31985)
+++ trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceChangesTestCase.java 2011-06-09 21:00:58 UTC (rev 31986)
@@ -21,8 +21,10 @@
import org.jboss.tools.ws.jaxrs.core.WorkbenchUtils;
import org.jboss.tools.ws.jaxrs.core.builder.AbstractMetamodelBuilderTestCase;
import org.jboss.tools.ws.jaxrs.core.metamodel.BaseElement.EnumKind;
+import org.jboss.tools.ws.jaxrs.core.metamodel.HTTPMethod;
import org.jboss.tools.ws.jaxrs.core.metamodel.MediaTypeCapabilities;
import org.jboss.tools.ws.jaxrs.core.metamodel.Resource;
+import org.jboss.tools.ws.jaxrs.core.metamodel.ResourceMethod;
import org.jboss.tools.ws.jaxrs.core.metamodel.Resources;
import org.junit.Assert;
import org.junit.Test;
@@ -291,9 +293,31 @@
Assert.assertTrue("Resource not marked with errors", fooResource.hasErrors());
// operation 2
WorkbenchUtils.addImport(fooResource.getJavaElement().getCompilationUnit(), Path.class.getName());
// post-conditions 2: errors reported (import is missing)
Assert.assertEquals(6, metamodel.getHttpMethods().size());
Assert.assertFalse("Resource still marked with errors", fooResource.hasErrors());
Assert.assertEquals("Wrong number of routes", 12, metamodel.getRoutes().getAll().size());
}
+
+ @Test
+ public void shouldReportErrorsWhenChangingPathParam() throws JavaModelException {
+ // pre-condition
+ Resource customersResource = metamodel.getResources().getByPath("/customers");
+ Assert.assertNotNull("CustomersResource not found", customersResource);
+ Assert.assertFalse("No error expected", customersResource.hasErrors());
+ HTTPMethod httpMethod = metamodel.getHttpMethods().getByVerb("GET");
+ ResourceMethod resourceMethod = customersResource.getByMapping(httpMethod, "{id}", null, null);
+ Assert.assertNotNull("ResourceMethod not found", resourceMethod);
+ // operation 1
+ WorkbenchUtils.replaceFirstOccurrenceOfCode(resourceMethod.getJavaElement(), "{id}", "{i}");
+ // post-conditions 1: error(s) reported
+ Assert.assertTrue("Resource not marked with errors", resourceMethod.hasErrors());
+ Assert.assertTrue("Resource not marked with errors", customersResource.hasErrors());
+ // operation 2
+ WorkbenchUtils.replaceFirstOccurrenceOfCode(resourceMethod.getJavaElement(), "{i}", "{id}");
+ // post-conditions 2: no error reported (PathParam value was fixed)
+ Assert.assertFalse("Resource still marked with errors", resourceMethod.hasErrors());
+ Assert.assertFalse("Resource still marked with errors", customersResource.hasErrors());
+
+ }
}
Modified: trunk/ws/tests/org.jboss.tools.ws.jaxrs.core.test/src/org/jboss/tools/ws/jaxrs/core/internal/builder/ResourceMethodChangesTestCase.java
===================================================================
@@ -291,9 +293,31 @@
// operation 2
WorkbenchUtils.addImport(fooResource.getJavaElement().getCompilationUnit(), Path.class.getName());
- // post-conditions 2: errors reported (import is missing)
+ // post-conditions 2: no error reported (import was restored)
Assert.assertEquals(6, metamodel.getHttpMethods().size());
Assert.assertFalse("Resource still marked with errors", fooResource.hasErrors());